@@ -84,6 +84,19 @@ def good_object_id(env):
     return env["OBJECT_ID"]
 
 
+@pytest.fixture(scope="session")
+def object_id_delimiter(env):
+    return env["OBJECT_ID_DELIMITER"]
+
+
+@pytest.fixture(scope="session")
+def separate_good_object_id(good_object_id, object_id_delimiter):
+    return {
+        "group": good_object_id.split(object_id_delimiter)[0],
+        "table": good_object_id.split(object_id_delimiter)[1]
+    }
+
+
 @pytest.fixture(scope="session")
 def bad_object_id(env):
     return env["OBJECT_ID"] + "_bad"
@@ -282,7 +295,9 @@ def five_column_100_row_dataset():
 
 @pytest.fixture(scope="session")
 def batch_rows():
-    return 200000
+    # obtained by reading two-million rows into a file and getting the file size. 2e6/77.05MB ~= 26000
+    # multiplied by 10 to load 10MB each time instead of 1
+    return 260000
 
 
 @pytest.fixture(scope="session")
@@ -303,37 +318,46 @@ def num_gigs(request):
 
 
 @pytest.fixture(scope="session")
-def load_data(connector, batch, good_object_id, mapping_object, _replace, num_gigs, batch_size, batch_rows):
+def load_data(connector, batch, separate_good_object_id, object_id_delimiter, mapping_object, _replace, num_gigs, batch_size, batch_rows):
     print(f"\nNow loading {num_gigs} GB!")
     size = num_gigs
-    object_id = "load_" + str(num_gigs) + "GB_" + good_object_id
+    object_id = separate_good_object_id["group"] + object_id_delimiter + "load_" + str(num_gigs) \
+                + "GB_" + separate_good_object_id["table"]
     batch_number = 1
     rows_loaded = 0
     elapsed_time = 0
-    total_batches = math.ceil((size * GB) / float(sys.getsizeof(batch)))
+
+    # defining a temp batch so it doesn't recreate dummy data each time batch is referenced
+    temp_batch = batch
+
+    # each batch is approximately 10 MB, so we divide the total desired file size by that
+    total_batches = math.ceil((size * GB) / 10 * MB)
+    memory_bytes = sys.getsizeof(temp_batch)
 
     start = time.time()
-    connector.load_data(batch, object_id, mapping_object, _replace, batch_number, total_batches)
+    connector.load_data(temp_batch, object_id, mapping_object, _replace, batch_number, total_batches)
     end = time.time()
     elapsed_time += (end - start)
 
     while batch_number <= total_batches:
-        rows_loaded += len(batch)
+        rows_loaded += len(temp_batch)
         print(f"Batch {batch_number}/{total_batches}: Loaded {rows_loaded} rows out of {total_batches * batch_rows} "
-              f"in {elapsed_time} seconds.")
+              f"in {elapsed_time} seconds. \nCurrent size in memory: {memory_bytes / MB} MB.")
         batch_number += 1
 
+        temp_batch = batch
+        memory_bytes = sys.getsizeof(temp_batch)
         start = time.time()
-        connector.load_data(batch, object_id, mapping_object, _replace, batch_number, total_batches)
+        connector.load_data(temp_batch, object_id, mapping_object, _replace, batch_number, total_batches)
         end = time.time()
         elapsed_time += (end - start)
 
     print(f"Loaded {rows_loaded} rows out of {total_batches * batch_rows}."
-          f"\nTotal size uploaded: {size * GB} bytes, which is {size} GB.")
+          f"\nTotal size uploaded: {size} GB.")
     with open("load_test_results.txt", "a") as f:
         f.write(f"LoadTest for {size} GB")
         f.write(f"Loaded {rows_loaded} rows out of {total_batches * batch_rows}."
-                f"\nTotal size uploaded: {size * GB} bytes, which is {size} GB.")
+                f"\nTotal size uploaded: {size} GB.\n")
 
         hours = math.floor(elapsed_time / (60. * 60.))
         minutes = math.floor((elapsed_time % (60. * 60.)) / 60.)
@@ -342,7 +366,6 @@ def load_data(connector, batch, good_object_id, mapping_object, _replace, num_gi
 
         print(f"Time elapsed to load {num_gigs} GB: {formatted_time}.")
         f.write(f"Time elapsed to load {num_gigs} GB: {formatted_time}.")
-        assert elapsed_time < (10. * 60.)
         return True
 
 
