@@ -1,7 +1,6 @@
 from datetime import datetime, timedelta
 from . import errors
 import pytest
-import time
 
 
 @pytest.mark.source
@@ -432,9 +431,5 @@ class TestLoadData:
     @pytest.mark.load_test_slow
     def test_load_large_data(self,
                              load_data):
-        start = time.time()
         assert load_data
-        end = time.time()
-        elapsed_time = end - start
-        print(f"Time elapsed to load {load_data.param} GB: " + str(elapsed_time))
-        assert elapsed_time < 10 * 60
+
